Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1486)

Unified Diff: chrome/browser/favicon/favicon_handler.h

Issue 10918186: Expire favicons which were added with default favicon sizes (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/extensions/extension_web_ui.cc ('k') | chrome/browser/favicon/favicon_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/favicon/favicon_handler.h
diff --git a/chrome/browser/favicon/favicon_handler.h b/chrome/browser/favicon/favicon_handler.h
index e92bf066f2f9c8125c7697c4edbec3c717469d6d..99defbdfdbddb9726035f91589f2fb9a0d4ca500 100644
--- a/chrome/browser/favicon/favicon_handler.h
+++ b/chrome/browser/favicon/favicon_handler.h
@@ -272,11 +272,11 @@ class FaviconHandler {
// See "Favicon Details" in tab_contents.cc for more details.
bool got_favicon_from_history_;
- // Whether the favicon is out of date. If true, it means history knows about
- // the favicon, but we need to download the favicon because the icon has
- // expired.
- // See "Favicon Details" in tab_contents.cc for more details.
- bool favicon_expired_;
+ // Whether the favicon is out of date or the favicon data in
+ // |history_results_| is known to be incomplete. If true, it means history
+ // knows about the favicon, but we need to download the favicon because the
+ // icon has expired or the data in the database is incomplete.
+ bool favicon_expired_or_incomplete_;
// Requests to the renderer to download favicons.
typedef std::map<int, DownloadRequest> DownloadRequests;
« no previous file with comments | « chrome/browser/extensions/extension_web_ui.cc ('k') | chrome/browser/favicon/favicon_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698